@@ -1,15 +1,21 @@
 package Task::BeLike::FIBO;
-use strict;
-use warnings;
-our $VERSION = '0.8';
+$VERSION = '0.9';
 1;
 
+__END__
+
 =encoding utf8
 
 =head1 NAME
 
 Task::BeLike::FIBO -- Leonardo Pisano a.k.a. Fibonacci
 
+=begin HTML
+
+<p><a href="https://metacpan.org/pod/Task::BeLike::FIBO" target="_blank"><img src="https://badge.fury.io/pl/Task-BeLike-FIBO.svg" alt="CPAN version"></a> <a href="https://travis-ci.org/fibo/Task-BeLike-FIBO-pm" target="_blank"><img src="https://travis-ci.org/fibo/Task-BeLike-FIBO-pm.svg?branch=master" alt="Build Status"></a></p>
+
+=end HTML
+
 =head1 SYNOPSIS
 
     cpan Task::BeLike::FIBO
@@ -34,12 +40,46 @@ Learn from nature: stay as minimal as possible.
 
 =head2 FILES
 
-Follows a list of sample files of a package, C<MY::Package> for instance.
+Follows a list of sample files of a package, named C<MY::Package> for instance: GitHub repo name hence is C<My-Package-pm>.
 
 =over 4
 
 =item *
 
+lib/My/Package.pm
+
+This is the main file of the package and looks something like this
+
+    package Task::BeLike::FIBO;
+    $VERSION = '0.1';
+    1;
+
+    __END__
+
+    =encoding utf8
+
+    =head1 NAME
+
+    My::Package -- is yet another Perl package
+
+    =begin HTML
+
+    <p><a href="https://metacpan.org/pod/TaskMy::Packagerget="_blank"><img src="https://badge.fury.io/pl/TaskMy-Package" alt="CPAN version"></a> <a href="https://travis-ci.org/fibo/TaskMy-Package target="_blank"><img src="https://travis-ci.org/fibo/TaskMy-Packagesvg?branch=master" alt="Build Status"></a></p>
+
+    =end HTML
+
+    =head1 DESCRIPTION
+
+    =head1 COPYRIGHT AND LICENSE
+
+    This software is copyright (c) 2014 by G. Casati.
+
+    This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
+
+    =cut
+
+=item *
+
 README.md
 
     My-Package
@@ -54,14 +94,12 @@ README.md
         make test
         make install
 
-    For more information point your browser to [online docs](https://metacpan.org/pod/My::Package)
+    For more information point your browser to [online docs](https://metacpan.org/pod/My::Package).
 
     --------
-    [![CPAN version](https://badge.fury.io/pl/My-Package-pm.svg)](https://metacpan.org/pod/My::Package)
+    [![CPAN version](https://badge.fury.io/pl/My-Package.svg)](https://metacpan.org/pod/My::Package)
     [![Build Status](https://travis-ci.org/fibo/My-Package-pm.png?branch=master)](https://travis-ci.org/fibo/My-Package-pm)
-    [![Coverage Status](https://coveralls.io/repos/fibo/My-Package-pm/badge.png?branch=master)](https://coveralls.io/r/fibo/My-Package-pm?branch=master)
-
-=item *
+    [![C
 
 .travis.yml
 
@@ -105,12 +143,14 @@ Makefile.PL
         VERSION_FROM  => 'lib/My/Package.pm',
         AUTHOR        => 'G. Casati <fibo@cpan.org>',
         NAME          => 'My::Package',
+        MIN_PERL_VERSION => '5.8.0',
         META_MERGE => {
-          resources => {
-            homepage   => 'https://metacpan.org/pod/My::Package'
-            license    => 'http://g14n.info/mit-license',
-            repository => 'http://github.com/fibo/My-Package-pm',
-            bugtracker => 'http://github.com/fibo/My-Package-pm/issues',
+            resources => {
+                homepage   => 'https://metacpan.org/pod/My::Package'
+                license    => 'http://g14n.info/artistic-license',
+                repository => 'https://github.com/fibo/My-Package-pm',
+                bugtracker => 'https://github.com/fibo/My-Package-pm/issues',
+            },
         },
         PREREQ_PM => {
             # 'Some::Package' => '0',
@@ -139,6 +179,15 @@ MANIFEST.SKIP
     ^blib
     ^pm_to_blib
 
+=item *
+
+Changes
+
+It is considered a good habit to keep track of at least major changes to inform users what they should expect when upgrading version.
+
+    2014-12-2 v0.1
+    + First release
+
 =back
 
 =head2 WORKFLOW
@@ -149,7 +198,7 @@ MANIFEST.SKIP
 
 Start a feature branch
 
-    git checkout -b somefeature
+    $ git checkout -b somefeature
 
 =item *
 
@@ -159,22 +208,22 @@ Write documentation about new feature. Then write tests to check it and code to
 
 Run tests
 
-    prove -l --state=save
+    $ prove -l --state=save
 
 =item *
 
 If some test does not pass, fix code and run tests that failed
 
-    prove -l --state=save,failed
+    $ prove -l --state=save,failed
 
 =item *
 
 Merge feature branch and commit work
 
-    git rebase master
-    git checkout master
-    git merge somefeature
-    git push
+    $ git rebase master
+    $ git checkout master
+    $ git merge somefeature
+    $ git push
 
 =item *
 
@@ -182,22 +231,25 @@ Update version, use L<Semantic Versioning|http://semver.org/>.
 
 Create a new release
 
-    perl Makefile.PL
-    make
-    make test
-    make manifest
-    make dist
-    make realclean
+    $ perl Makefile.PL
+    $ make
+    $ make test
+    $ make manifest
+    $ make dist
+    $ make realclean
 
 =item *
 
 Upload to L<PAUSE|http://pause.perl.org/>
 
-    cpan-upload -u fibo My-Package-0.1.tar.gz
+    $ cpan-upload -u fibo My-Package-0.1.tar.gz
+    PAUSE Password:
+    registering upload with PAUSE web server
+    POSTing upload for My-Package-0.1.tar.gz to https://pause.perl.org/pause/authenquery
+    PAUSE add message sent ok [200]
 
 =back
 
-
 =head1 STUFF INCLUDED
 
 =over 4
@@ -210,7 +262,7 @@ See how to setup L<A CPAN client that works like a charm|http://g14n.info/2014/0
 
 =item *
 
-L<CPAN::Uploader>
+L<CPAN::Uploader> to release modules using a cli. It also depends on L<LWP::Protocol::https> which depends on L<IO::Socket::SSL> which I think L<should be a core module|http://blogs.perl.org/users/chris_fedde/2013/03/how-do-we-know-when-a-module-is-depricated.html#comment-1460139>.
 
 =item *
 
@@ -234,7 +286,8 @@ Create a C<t/_compile.t> file
     use warnings;
     use Test::More;
     
-    eval "use Test::Compile";
+   
+    e Test::Compile";
     Test::More->builder->BAIL_OUT(<<EOF) if $@;
     Test::Compile required for testing compilation
     EOF
@@ -255,14 +308,22 @@ Create a C<t/_pod.t> file
     use warnings;
     use Test::More;
     
-    eval "use Test::Pod";
+    eva
+    st::Pod";
     Test::More->builder->BAIL_OUT(<<EOF) if $@;
     Test::Pod required for testing compilation
     EOF
     
-    all_pod_files_ok();
+    all_pod
+    ();
 
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by G. Casati.
+
+This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
+
 =cut
 
